🚀 Installation
---------------

PyPI
~~~~

.. code-block:: bash

   pip install delnx

Development version
~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: bash

   pip install git+https://github.com/joschif/delnx.git@main

Installing `cuml`
~~~~~~~~~~~~~~~~~~

Using the cuml backend requires a working installation of `cuml` from RAPIDS. For this please refer to the `RAPIDS installation guide <https://docs.rapids.ai/install/>`_.


Installing `JAX`
~~~~~~~~~~~~~~~~~~

Most methods in **delnx** are implemented in JAX, which allows for GPU acceleration. To install JAX, follow the instructions on the `JAX installation page <https://jax.readthedocs.io/en/latest/installation.html>`_.
